@@ -1,7 +1,10 @@
-import pytest
+import pytest, pytz
+from datetime import datetime
 from collections import Counter
+
+import pytz
 from icecream import ic
-from limeutils import utils, listify, valid_str_only
+from limeutils import utils, listify, valid_str_only, istimezone, utc_to_offset
 
 
 param = [(3, True), (3.0, True), (0, True), ('3.4', True), ('0.4', True), ('0.0', True),
@@ -75,10 +78,43 @@ param = [
     (set(), False, False), ('', False, False), (True, True, True), (False, True, False)
 ]
 @pytest.mark.parametrize('item, allow, out', param)
-@pytest.mark.focus
+# @pytest.mark.focus
 def test_valid_str_only(item, allow, out):
     if allow:
         assert valid_str_only(item, allow_bool=True) == out
     else:
         assert valid_str_only(item) == out
-        
\ No newline at end of file
+
+
+param = [
+    ('-1200', True), ('-0800', True), ('-0330', True), ('-0100', True),
+    ('+0800', True), ('+0000', True), ('+1300', True), ('+0100', True),
+    ('0800', False), ('0000', False), ('1300', False),
+    ('+1500', False), ('-1300', False)
+]
+@pytest.mark.parametrize('tz, out', param)
+# @pytest.mark.focus
+def test_istimezone(tz, out):
+    assert istimezone(tz) == out
+
+
+param = [
+    (datetime(2020, 1, 1, 10, 30, 1, tzinfo=pytz.UTC), '+0000', '2020-01-01 10:30:01 +0000'),
+    (datetime(2020, 1, 1, 10, 30, 1, tzinfo=pytz.UTC), '+0100', '2020-01-01 11:30:01 +0100'),
+    (datetime(2020, 1, 1, 10, 30, 1, tzinfo=pytz.UTC), '+0500', '2020-01-01 15:30:01 +0500'),
+    (datetime(2020, 1, 1, 10, 30, 1, tzinfo=pytz.UTC), '+1200', '2020-01-01 22:30:01 +1200'),
+    (datetime(2020, 1, 1, 10, 30, 1, tzinfo=pytz.UTC), '-0330', '2020-01-01 07:00:01 -0330'),
+    (datetime(2020, 1, 1, 20, 30, 1, tzinfo=pytz.UTC), '+0900', '2020-01-02 05:30:01 +0900'),
+    (datetime(2020, 1, 1, 20, 30, 1, tzinfo=pytz.UTC), '-0200', '2020-01-01 18:30:01 -0200'),
+    (datetime(2020, 1, 1, 20, 30, 1, tzinfo=pytz.UTC), '-1200', '2020-01-01 08:30:01 -1200'),
+    (datetime(2020, 1, 1, 3, 30, 1, tzinfo=pytz.UTC), '-0700', '2019-12-31 20:30:01 -0700'),
+]
+@pytest.mark.parametrize('basedate, offset, datestr', param)
+# @pytest.mark.focus
+def test_utc_to_offset(basedate, offset, datestr):
+    date_format = '%Y-%m-%d %H:%M:%S %z'
+
+    newdate = utc_to_offset(basedate, offset)
+    assert isinstance(newdate, datetime)
+    assert newdate.strftime('%z') == offset
+    assert newdate.strftime(date_format) == datestr
\ No newline at end of file
